@@ -277,6 +277,12 @@ def _main():
         retval = mainFunc(args, config)
     except KeyboardInterrupt:
         retval = 0
+    except BrokenPipeError:
+        # Python flushes standard streams on exit; redirect remaining output
+        # to devnull to avoid another BrokenPipeError at shutdown
+        devnull = os.open(os.devnull, os.O_WRONLY)
+        os.dup2(devnull, sys.stdout.fileno())
+        retval = 1
     except (StopIteration, IOError) as ex:
         eyed3.utils.console.printError(str(ex))
         retval = 1
