@@ -620,7 +620,8 @@ optional. For example, 2012-03 is valid, 2012--12 is not.
             # UFID
             for ufid in tag.unique_file_ids:
                 printMsg("%s [%s] : %s" %
-                        (boldText("Unique File ID:"), ufid.owner_id,
+                        (boldText("Unique File ID:"),
+                         ufid.owner_id.decode("unicode_escape"),
                          ufid.uniq_id.decode("unicode_escape")))
 
             # COMM
@@ -655,8 +656,8 @@ optional. For example, 2012-03 is valid, 2012--12 is not.
 
             # user url frames
             for u in tag.user_url_frames:
-                printMsg("%s [Description: %s]: %s" % (u.id, u.description,
-                                                       u.url))
+                printMsg("%s: [Description: %s]\n%s" %
+                         (boldText("UserURLFrame"), u.description, u.url))
 
             # APIC
             for img in tag.images:
@@ -1004,7 +1005,7 @@ optional. For example, 2012-03 is valid, 2012--12 is not.
 
         # --remove-frame
         for fid in self.args.remove_fids:
-            assert(isinstance(fid, bytes))
+            assert isinstance(fid, bytes)
             if fid in tag.frame_set:
                 del tag.frame_set[fid]
                 retval = True
